@@ -16,6 +16,10 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, ForceTorque):
             return obj.__dict__
+        elif isinstance(obj, Script):
+            return obj.__dict__
+        elif isinstance(obj, WaypointConfig):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -38,6 +42,10 @@ class JsonDecoder(json.JSONDecoder):
                 return Poses(**obj)
             if '_type' in obj and obj['_type'] == 'force_torque':
                 return ForceTorque(**obj)
+            if '_type' in obj and obj['_type'] == 'script':
+                return Script(**obj)
+            if '_type' in obj and obj['_type'] == 'waypoint_config':
+                return WaypointConfig(**obj)
         return obj
 
 
